@@ -132,7 +132,8 @@ def is_file_or_url(filename, msg='checking existence of', debug=True):
                 errwarn('... ' +  msg + ' ' +  filename + ' ...')
             import urllib.request, urllib.error, urllib.parse
             f = urllib.request.urlopen(filename, timeout=10)
-            text = f.read()
+            content = f.read()
+            content_type_str = f.getheader('Content-Type')
             f.close()
             ext = os.path.splitext(filename)[1]
             if ext in ('.html', 'htm'):
@@ -146,25 +147,28 @@ def is_file_or_url(filename, msg='checking existence of', debug=True):
                     errwarn('    found!')
                 return 'url'
             else:
-                # Seemingly successful opening of a file, but check if
-                # this is a special GitHub error message file
-                special_hosts = ('github', 'www.uio.no', 'openclipart.org')
-                special_host = False
-                for host in special_hosts:
-                    if host in filename:
-                        special_host = True
-                        break
-                if special_host and (
-                    '>404' in text # <title>404 ...?
-                    or 'Not Found' in text):
-                    # HTML file with an error message: file not found
-                    if msg or debug:
-                        errwarn('    %s not found' % filename)
+                if 'text/html' in content_type_str:
+                    # assume utf-8 encoding
+                    text = content.decode('utf-8')
+                    # Seemingly successful opening of a file, but check if
+                    # this is a special GitHub error message file
+                    special_hosts = ('github', 'www.uio.no', 'openclipart.org')
+                    special_host = False
+                    for host in special_hosts:
+                        if host in filename:
+                            special_host = True
+                            break
+                    if special_host and (
+                        '>404' in text # <title>404 ...?
+                        or 'Not Found' in text):
+                        # HTML file with an error message: file not found
+                        if msg or debug:
+                            errwarn('    %s not found' % filename)
                         return None
-                else:
-                    if msg or debug:
-                        errwarn('    found!')
-                    return 'url'
+
+                if msg or debug:
+                    errwarn('    found!')
+                return 'url'
         except IOError as e:
             if msg or debug:
                 errwarn('    not found!')
